@@ -54,7 +54,8 @@ setConstructorS3("AffinePlm", function(..., background=TRUE) {
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   args <- list(...);
   if (length(args) > 0 && !is.null(args[[1]])) {
-    require("aroma.light") || throw("Package not loaded: aroma.light");
+    # Early error, iff package is missing
+    requireNamespace("aroma.light") || throw("Package not loaded: aroma.light");
   }
 
   this <- extend(ProbeLevelModel(...), "AffinePlm",
@@ -160,7 +161,7 @@ setMethodS3("getFitUnitGroupFunction", "AffinePlm", function(this, ...) {
 
     # NOTE: If center=FALSE => constraint a=0 /HB 2006-09-11
     y <- t(y);
-    f <- calibrateMultiscan(y, center=center, project=TRUE);
+    f <- .calibrateMultiscan(y, center=center, project=TRUE);
     theta <- as.vector(f);
     phi <- as.vector(attr(f, "modelFit")$b);
 
