@@ -60,7 +60,7 @@ setMethodS3("createUniqueCdf", "AffymetrixCdfFile", function(this, chipType=getC
       group;
     } # rearrangeGroup()
 
-    nbrOfCells <- base::lapply(units, FUN=function(unit) .subset2(unit, "ncells"));
+    nbrOfCells <- lapply(units, FUN=function(unit) .subset2(unit, "ncells"));
     nbrOfCells <- sum(unlist(nbrOfCells, use.names=FALSE));
 
     cells <- seq(from=offset+1, to=offset+nbrOfCells);
@@ -175,7 +175,7 @@ setMethodS3("createUniqueCdf", "AffymetrixCdfFile", function(this, chipType=getC
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Get the number of groups per units
   verbose && enter(verbose, "Reading CDF group names");
-  nbrOfGroupsPerUnit <- readCdfGroupNames(src);
+  nbrOfGroupsPerUnit <- .readCdfGroupNames(src);
   verbose && exit(verbose);
 
   names(nbrOfGroupsPerUnit) <- NULL;
@@ -195,7 +195,7 @@ setMethodS3("createUniqueCdf", "AffymetrixCdfFile", function(this, chipType=getC
   # Q: Why is readCdf(..., stratifyBy=<vector>) not throwing?
   #    Error in match.arg(stratifyBy) : 'arg' must be of length 1
   #    /HB 2011-04-15
-  cdfLite <- readCdf(src, units=units,
+  cdfLite <- .readCdf(src, units=units,
               readXY=FALSE, readBases=FALSE,
               readIndexpos=FALSE, readAtoms=FALSE,
               readUnitType=FALSE, readUnitDirection=FALSE,
@@ -225,10 +225,10 @@ setMethodS3("createUniqueCdf", "AffymetrixCdfFile", function(this, chipType=getC
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Keep all QC units
   verbose && enter(verbose, "Reading CDF QC units");
-  destQcUnits <- readCdfQc(src);
+  destQcUnits <- .readCdfQc(src);
   verbose && exit(verbose);
   nbrOfQcUnits <- length(destQcUnits);
-  nbrOfCellsPerQcUnit <- base::lapply(destQcUnits, FUN=.subset2, "ncells");
+  nbrOfCellsPerQcUnit <- lapply(destQcUnits, FUN=.subset2, "ncells");
   nbrOfCellsPerQcUnit <- unlist(nbrOfCellsPerQcUnit, use.names=FALSE);
   nbrOfQcCells <- sum(nbrOfCellsPerQcUnit);
   verbose && printf(verbose,
@@ -265,7 +265,7 @@ setMethodS3("createUniqueCdf", "AffymetrixCdfFile", function(this, chipType=getC
 
   # Get template header
   verbose && enter(verbose, "Reading CDF header");
-  destHeader <- readCdfHeader(src);
+  destHeader <- .readCdfHeader(src);
   verbose && exit(verbose);
 
   # Update CDF header dimension
@@ -274,7 +274,7 @@ setMethodS3("createUniqueCdf", "AffymetrixCdfFile", function(this, chipType=getC
 
   # Get unit names
   verbose && enter(verbose, "Reading CDF unit names");
-  unitNames <- readCdfUnitNames(src);
+  unitNames <- .readCdfUnitNames(src);
   verbose && exit(verbose);
 
   if (nbrOfUnits > 0) {
@@ -320,7 +320,7 @@ setMethodS3("createUniqueCdf", "AffymetrixCdfFile", function(this, chipType=getC
   });
 
   # Allocate/write CDF header
-  writeCdfHeader(con=con, destHeader, unitNames=unitNames,
+  .writeCdfHeader(con=con, destHeader, unitNames=unitNames,
                     qcUnitLengths=qcUnitLengths, unitLengths=unitLengths,
                                                         verbose=verbose2);
   # Not needed anymore
@@ -347,7 +347,7 @@ setMethodS3("createUniqueCdf", "AffymetrixCdfFile", function(this, chipType=getC
   verbose && exit(verbose);
 
   # Write QC units
-  writeCdfQcUnits(con=con, destQcUnits, verbose=verbose2);
+  .writeCdfQcUnits(con=con, destQcUnits, verbose=verbose2);
   # Not needed anymore
   destQcUnits <- NULL; # Not needed anymore
 
@@ -406,7 +406,7 @@ setMethodS3("createUniqueCdf", "AffymetrixCdfFile", function(this, chipType=getC
 
     # Read CDF structure
     verbose && enter(verbose, "Reading CDF list structure");
-    srcUnits <- readCdf(src, units=units, readGroupDirection=TRUE);
+    srcUnits <- .readCdf(src, units=units, readGroupDirection=TRUE);
     verbose && exit(verbose);
 
     # Sanity check
@@ -429,11 +429,11 @@ setMethodS3("createUniqueCdf", "AffymetrixCdfFile", function(this, chipType=getC
     }
 
     # Precalculate
-    srcUnits <- base::lapply(srcUnits, FUN=function(unit) {
+    srcUnits <- lapply(srcUnits, FUN=function(unit) {
       groups <- .subset2(unit, "groups");
-      groups <- base::lapply(groups, FUN=function(group) {
+      groups <- lapply(groups, FUN=function(group) {
 		nThisGroup <- length(.subset2(group,"pbase"));
-        #group[fields] <- base::lapply(.subset(group, fields), FUN=.subset, fIdxs);
+        #group[fields] <- lapply(.subset(group, fields), FUN=.subset, fIdxs);
         #group$natoms <- nThisGroup
         #group$ncellsperatom <- as.integer(1);
         idxs <- idxOffset + seq_len(nThisGroup);
@@ -462,7 +462,7 @@ setMethodS3("createUniqueCdf", "AffymetrixCdfFile", function(this, chipType=getC
 #    verbose && str(verbose, srcUnits[1]);
 
     # Write regular units
-    writeCdfUnits(con=con, srcUnits, verbose=verbose2);
+    .writeCdfUnits(con=con, srcUnits, verbose=verbose2);
     # Not needed anymore
     srcUnits <- units <- NULL; # Not needed anymore
 
@@ -496,7 +496,7 @@ setMethodS3("createUniqueCdf", "AffymetrixCdfFile", function(this, chipType=getC
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   verbose && enter(verbose, "Verifying the written CDF");
   # Checking header
-  header <- readCdfHeader(pathnameT);
+  header <- .readCdfHeader(pathnameT);
 
   # Validation array dimension
   if ((header$nrows != nrows) || (header$ncols != ncols)) {
@@ -512,7 +512,7 @@ setMethodS3("createUniqueCdf", "AffymetrixCdfFile", function(this, chipType=getC
     verbose && printf(verbose, "Chunk %d of %d\n", kk, nbrOfChunks);
     from <- (kk-1)*chunkSize+1;
     to <- min(from+chunkSize, nbrOfUnits);
-    cells <- readCdfCellIndices(pathnameT, units=from:to);
+    cells <- .readCdfCellIndices(pathnameT, units=from:to);
     cells <- unlist(cells, use.names=FALSE);
     cells <- diff(cells);
     cells <- unique(cells);
@@ -551,7 +551,7 @@ setMethodS3("createUniqueCdf", "AffymetrixCdfFile", function(this, chipType=getC
   stopifnot(identical(nbrOfGroupsPerUnit(cdfU), nbrOfGroupsPerUnit(this)));
 
   verbose && cat(verbose, "Groups names per unit");
-  stopifnot(identical(readCdfGroupNames(getPathname(cdfU)), readCdfGroupNames(getPathname(this))));
+  stopifnot(identical(.readCdfGroupNames(getPathname(cdfU)), .readCdfGroupNames(getPathname(this))));
 
   verbose && cat(verbose, "Number of cells per unit group");
   stopifnot(identical(nbrOfCellsPerUnitGroup(cdfU), nbrOfCellsPerUnitGroup(this)));
