@@ -1,7 +1,7 @@
 setMethodS3("writeCdfByExcludingCells", "AffymetrixCdfFile", function(this, tags=c("filtered"), cellsToExclude, dropEmptyGroups=TRUE, dropEmptyUnits=dropEmptyGroups, ..., overwrite=FALSE, ram=1, verbose=FALSE) {
-  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
+  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Validate arguments
-  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
+  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    maxNbrOfCells <- nbrOfCells(this);
 
   # Argument 'tags':
@@ -46,10 +46,10 @@ setMethodS3("writeCdfByExcludingCells", "AffymetrixCdfFile", function(this, tags
   verbose && cat(verbose, "Path: ", path);
 
   # Get CDF header (to be reused when writing the new CDF)
-  cdfHeader <- readCdfHeader(pathname);
+  cdfHeader <- .readCdfHeader(pathname);
 
   # Get CDF QC units (to be reused when writing the new CDF)
-  cdfQcUnits <- readCdfQc(pathname);
+  cdfQcUnits <- .readCdfQc(pathname);
 
   verbose2 <- as.logical(verbose);
 
@@ -79,9 +79,9 @@ setMethodS3("writeCdfByExcludingCells", "AffymetrixCdfFile", function(this, tags
   cdfListF <- vector("list", length=nbrOfUnits);
   names(cdfListF) <- getUnitNames(this);
 
-  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
+  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Reading CDF, dropping cells, ...
-  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
+  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   nbrOfUnitsLeft <- length(units);
   chunk <- 1L;
   while (nbrOfUnitsLeft > 0) {
@@ -103,7 +103,7 @@ setMethodS3("writeCdfByExcludingCells", "AffymetrixCdfFile", function(this, tags
     stopifnot(length(unitsChunk) > 0);
 
     verbose && enter(verbose, "Reading subset of units from source CDF");
-    cdfListChunk <- readCdf(pathname, readIndices=TRUE, units=unitsChunk);
+    cdfListChunk <- .readCdf(pathname, readIndices=TRUE, units=unitsChunk);
     verbose && exit(verbose);
 
     verbose && enter(verbose, "Dropping cells");
@@ -151,9 +151,9 @@ setMethodS3("writeCdfByExcludingCells", "AffymetrixCdfFile", function(this, tags
 
 
 
-  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
+  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Drop empty units?
-  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
+  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   if (dropEmptyUnits) {
     verbose && enter(verbose, "Dropping empty units");
 
@@ -175,18 +175,18 @@ setMethodS3("writeCdfByExcludingCells", "AffymetrixCdfFile", function(this, tags
   } # if (dropEmptyUnits)
 
 
-  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
+  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Writing CDF
-  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
+  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   verbose && enter(verbose, "Writing filtered CDF");
   if (overwrite && isFile(pathnameF)) {
      file.remove(pathnameF);
   }
 
   # Write to a temporary file
-  pathnameT <- pushTemporaryFile(pathnameF, verbose=verbose);  
-  
-  writeCdf(pathnameT, cdfheader=cdfHeader, cdf=cdfListF, cdfqc=cdfQcUnits, verbose=verbose2);
+  pathnameT <- pushTemporaryFile(pathnameF, verbose=verbose);
+
+  .writeCdf(pathnameT, cdfheader=cdfHeader, cdf=cdfListF, cdfqc=cdfQcUnits, verbose=verbose2);
 
   # Not needed anymore
   cdfHeader <- cdfListF <- NULL; # Not needed anymore
@@ -204,9 +204,9 @@ setMethodS3("writeCdfByExcludingCells", "AffymetrixCdfFile", function(this, tags
   verbose && exit(verbose);
 
 
-  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
+  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Return new CDF
-  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
+  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   cdfF <- newInstance(this, pathnameF);
   verbose && print(verbose, cdfF);
 
