@@ -193,19 +193,22 @@ setMethodS3("getExpectedOutputFullnames", "MatSmoothing", function(this, ..., ve
 # }
 #*/###########################################################################
 setMethodS3("process", "MatSmoothing", function(this, ..., units=NULL, force=FALSE, verbose=FALSE) {
-  # gsmoothr::tmeanC()
-  require("gsmoothr") || throw("Package not loaded: gsmoothr");
+  requireNamespace("gsmoothr") || throw("Package not loaded: gsmoothr")
+  tmeanC <- gsmoothr::tmeanC;
+
 
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Local functions
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # internal function to do trimmed mean smoothing
+  # Lookup gsmoothr::tmeanC() once; '::' is expensive
+  gsmoothr_tmeanC <- gsmoothr::tmeanC;
   calcSmoothed <- function(posVector, dataMatrix, probeWindow, nProbes, meanTrim) {
     nc <- ncol(dataMatrix);
     posM <- matrix(posVector, nrow=length(posVector), ncol=nc);
     o <- order(posM);  # calculate ordering
 
-    smoothedScore <- gsmoothr::tmeanC(posM[o], dataMatrix[o],
+    smoothedScore <- gsmoothr_tmeanC(posM[o], dataMatrix[o],
            probeWindow=probeWindow, nProbes=nProbes*nc, trim=meanTrim);
     subsetInd <- seq(from=1, to=length(o), by=nc);
     return(smoothedScore[subsetInd]);
@@ -217,7 +220,7 @@ setMethodS3("process", "MatSmoothing", function(this, ..., units=NULL, force=FAL
   calcNullDist0 <- function(ch, ps, x) {
     MIN <- -999999
     #inds <-
-    y <- rep(MIN,length(x))
+    y <- rep(MIN, times=length(x))
     n <- length(ch)
     indices <- split(seq_len(n), ch)
     nChr <- length(indices)
@@ -427,7 +430,7 @@ setMethodS3("process", "MatSmoothing", function(this, ..., units=NULL, force=FAL
     unit$groups[[1]]$indices;
   });
 
-  nRows <- base::sapply(cellsList, FUN=length);
+  nRows <- sapply(cellsList, FUN=length);
   allInds <- unlist(cellsList, use.names=FALSE);
 
   nbrOfUnits <- length(units);
@@ -491,7 +494,7 @@ setMethodS3("process", "MatSmoothing", function(this, ..., units=NULL, force=FAL
     dsII <- NULL;
     verbose && exit(verbose);
 
-    dataList <- base::lapply(dataList, FUN=function(u) {
+    dataList <- lapply(dataList, FUN=function(u) {
       matrix(log2(u[[1]]$intensities), ncol=length(sampsKeep))
     });
 
@@ -605,7 +608,7 @@ setMethodS3("process", "MatSmoothing", function(this, ..., units=NULL, force=FAL
 
     verbose && enter(verbose, "Updating data file");
     verbose2 <- isVisible(verbose, -50);
-    updateCel(pathnameT, indices=allInds, intensities=matScores,
+    .updateCel(pathnameT, indices=allInds, intensities=matScores,
                                                         verbose=verbose2);
     verbose && exit(verbose);
 
