@@ -242,7 +242,7 @@ setMethodS3("process", "ScaleNormalization3", function(this, ..., skip=FALSE, fo
   verbose && enter(verbose, "Normalizing ", length(dataSet), " arrays");
   for (kk in seq_along(dataSet)) {
     verbose && enter(verbose, "Array #", kk);
-    df <- getFile(dataSet, kk);
+    df <- dataSet[[kk]];
     verbose && print(verbose, df);
 
     filename <- basename(getPathname(df));
