@@ -253,7 +253,7 @@ setMethodS3("findUnitsTodo", "WeightsFile", function(this, units=NULL, ..., forc
     verbose && exit(verbose);
 
     verbose && enter(verbose, "Extracting first cell in the first block for each unit");
-    idxs <- applyCdfGroups(idxs, function(groups) {
+    idxs <- .applyCdfGroups(idxs, function(groups) {
       # == groups[[1]]$indices[1];
       .subset(.subset2(.subset2(groups, 1), "indices"), 1)
     });
@@ -272,7 +272,7 @@ setMethodS3("findUnitsTodo", "WeightsFile", function(this, units=NULL, ..., forc
 
   # Read one cell from each unit
   verbose && enter(verbose, "Reading data for these ", length(idxs), " cells");
-  value <- readCel(getPathname(this), indices=idxs, readIntensities=FALSE,
+  value <- .readCel(getPathname(this), indices=idxs, readIntensities=FALSE,
                    readStdvs=TRUE, readPixels=FALSE)$stdvs;
   verbose && exit(verbose);
 
@@ -336,7 +336,7 @@ setMethodS3("getUnitGroupCellMap", "WeightsFile", function(this, units=NULL, ...
   }
 
   unitNames <- names(cells);
-  unitSizes <- unlist(base::lapply(cells, FUN=length), use.names=FALSE);
+  unitSizes <- unlist(lapply(cells, FUN=length), use.names=FALSE);
   cells <- unlist(cells, use.names=FALSE);
   verbose && exit(verbose);
 
@@ -459,7 +459,7 @@ setMethodS3("updateDataFlat", "WeightsFile", function(this, data, ..., verbose=F
   data <- data[,keep];
   pathname <- getPathname(this);
   pathname <- Arguments$getWritablePathname(pathname);
-  updateCel(pathname, indices=indices, data, verbose=verbose2);
+  .updateCel(pathname, indices=indices, data, verbose=verbose2);
   verbose && exit(verbose);
 
   verbose && exit(verbose);
