@@ -252,7 +252,9 @@ setMethodS3("doRMA", "AffymetrixCelSet", function(csR, arrays=NULL, flavor=c("af
 
 
 setMethodS3("doRMA", "default", function(dataSet, ..., verbose=FALSE) {
-  require("aroma.affymetrix") || throw("Package not loaded: aroma.affymetrix");
+  .require <- require
+  .require("aroma.affymetrix") || throw("Package not loaded: aroma.affymetrix")
+
 
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Validate arguments
