@@ -49,8 +49,8 @@ toPNG(getFullName(ces), tags=c(chrTag), {
   layout(matrix(seq_along(ces), ncol=2, byrow=TRUE));
   par(mar=c(3.5,4,1.5,1), mgp=c(1.8,0.5,0), pch=".");
   for (ii in seq_along(ces)) {
-    ce <- getFile(ces, ii);
-    gc <- getFile(callSet, ii);
+    ce <- ces[[ii]];
+    gc <- callSet[[ii]];
     data <- extractTotalAndFracB(ce, units=units, drop=TRUE);
     calls <- extractGenotypes(gc, units=units, drop=TRUE);
     col <- c(AA=1, AB=2, BB=3)[calls];
